# gswarm Architecture

## Overview

gswarm is a distributed GPU cluster management system that combines GPU profiling, model management, data pooling, and task orchestration into a unified platform.

## System Architecture 